@@ -11,7 +11,7 @@ has _http_response => ( isa => 'HTTP::Response', is => 'rw',
                             http_code    => 'code',
                         }
                       );
-has _twitter_error => ( isa => 'HashRef', is => 'rw', predicate => 'has_error',
+has _twitter_error => ( isa => 'HashRef|Object', is => 'rw', predicate => 'has_error',
                         clearer => '_clear_error' );
 
 has _error_return_val => ( isa => 'Maybe[ArrayRef]', is => 'rw', default => undef );
@@ -36,8 +36,10 @@ around _parse_result => sub {
 
         $self->_twitter_error($@->has_twitter_error
             ? $@->twitter_error
-            : { error => "TWITTER RETURNED ERROR MESSAGE BUT PARSING OF JSON RESPONSE FAILED - "
-                         . $res->message }
+            : $self->_inflate_objects({
+                  error => "TWITTER RETURNED ERROR MESSAGE BUT PARSING OF JSON RESPONSE FAILED - "
+                         . $res->message
+              })
         );
         $r = $self->_error_return_val;
     }
